@@ -153,7 +153,7 @@ int Application::exec(int argc, const char *const *argv)
     return QCoreApplication::exec();
 }
 
-int assignIntegerFromArg(const Argument &arg, int &integer)
+static int assignIntegerFromArg(const Argument &arg, int &integer)
 {
     if (!arg.isPresent()) {
         return 0;
@@ -226,6 +226,11 @@ int Application::loadConfig()
         return res;
     }
 
+    // read request timeout
+    if (const int res = assignIntegerFromArg(m_args.requestTimeout, m_settings.requestTimeout)) {
+        return res;
+    }
+
     // disable polling for information which is not used by any CLI operation so far
     m_settings.trafficPollInterval = 0;
     m_settings.devStatsPollInterval = 0;
@@ -359,7 +364,7 @@ void Application::requestRescan(const ArgumentOccurrence &occurrence)
         ++m_expectedResponse;
     }
     if (!m_expectedResponse) {
-        cerr << Phrases::Error << "No (valid) directories specified." << Phrases::End << flush;
+        cerr << Phrases::Error << "No (valid) folders specified." << Phrases::End << flush;
         exit(1);
     }
     cerr << flush;
@@ -369,7 +374,7 @@ void Application::requestRescanAll(const ArgumentOccurrence &)
 {
     m_expectedResponse = m_connection.dirInfo().size();
     connect(&m_connection, &SyncthingConnection::rescanTriggered, this, &Application::handleResponse);
-    cerr << "Request rescanning all directories ..." << endl;
+    cerr << "Request rescanning all folders ..." << endl;
     m_connection.rescanAllDirs();
 }
 
@@ -385,7 +390,7 @@ void Application::requestPauseResume(bool pause)
         connect(&m_connection, &SyncthingConnection::directoryResumeTriggered, this, &Application::handleResponse);
     }
     if (m_relevantDirs.empty() && m_relevantDevs.empty()) {
-        cerr << Phrases::Error << "No directories or devices specified." << Phrases::End << flush;
+        cerr << Phrases::Error << "No folders or devices specified." << Phrases::End << flush;
         exit(1);
     }
     if (!m_relevantDirs.empty()) {
@@ -395,9 +400,9 @@ void Application::requestPauseResume(bool pause)
             dirIds << dir.dirObj->id;
         }
         if (pause) {
-            cerr << "Request pausing directories ";
+            cerr << "Request pausing folders ";
         } else {
-            cerr << "Request resuming directories ";
+            cerr << "Request resuming folders ";
         }
         cerr << dirIds.join(QStringLiteral(", ")).toLocal8Bit().data() << " ...\n";
         if (pause ? m_connection.pauseDirectories(dirIds) : m_connection.resumeDirectories(dirIds)) {
@@ -421,7 +426,7 @@ void Application::requestPauseResume(bool pause)
         }
     }
     if (!m_expectedResponse) {
-        cerr << Phrases::Warning << "No directories or devices altered." << Phrases::End << flush;
+        cerr << Phrases::Warning << "No folders or devices altered." << Phrases::End << flush;
         exit(0);
     }
     cerr << flush;
@@ -497,7 +502,7 @@ bool Application::findPwd()
     }
 
     // handle error
-    cerr << Phrases::Error << "The current working directory \"" << pwd.toLocal8Bit().data() << "\" is not (part of) a Syncthing directory.";
+    cerr << Phrases::Error << "The current working directory \"" << pwd.toLocal8Bit().data() << "\" is not (part of) a Syncthing folder.";
     cerr << Phrases::End << flush;
     QCoreApplication::exit(2);
     return false;
@@ -506,8 +511,15 @@ bool Application::findPwd()
 void Application::printDir(const RelevantDir &relevantDir) const
 {
     const SyncthingDir *const dir = relevantDir.dirObj;
-    cout << " - " << TextAttribute::Bold << dir->id.toLocal8Bit().data() << '\n' << TextAttribute::Reset;
-    printProperty("Label", dir->label);
+    cout << " - " << TextAttribute::Bold;
+    if (dir->label.isEmpty()) {
+        cout << dir->id.toLocal8Bit().data() << '\n' << TextAttribute::Reset;
+    } else {
+        cout << dir->label.toLocal8Bit().data() << '\n' << TextAttribute::Reset;
+        if (dir->id != dir->label) {
+            printProperty("ID", dir->id);
+        }
+    }
     printProperty("Path", dir->path);
     printProperty("Status", dir->statusString());
     if (!dir->paused) {
@@ -558,6 +570,7 @@ void Application::printDev(const SyncthingDev *dev) const
     printProperty("Cert name", dev->certName);
     printProperty("Connection address", dev->connectionAddress);
     printProperty("Connection type", dev->connectionType);
+    printProperty("Connection local", dev->connectionLocal);
     printProperty("Client version", dev->clientVersion);
     printProperty("Last seen", dev->lastSeen);
     if (dev->totalIncomingTraffic > 0) {
@@ -602,7 +615,7 @@ void Application::printStatus(const ArgumentOccurrence &)
         if (!EscapeCodes::enabled) {
             printProperty("Status", statusString);
         } else {
-            printProperty("Status", argsToString('\e', '[', statusColor, 'm', statusString, "\e[0m"));
+            printProperty("Status", argsToString('\033', '[', statusColor, 'm', statusString, "\033[0m"));
         }
         printProperty("Global", directoryStatusString(overallStats.global), nullptr, 6);
         printProperty("Local", directoryStatusString(overallStats.local), nullptr, 6);
@@ -622,7 +635,7 @@ void Application::printStatus(const ArgumentOccurrence &)
 
     // display dirs
     if (!m_relevantDirs.empty()) {
-        cout << TextAttribute::Bold << "Directories\n" << TextAttribute::Reset;
+        cout << TextAttribute::Bold << "Folders\n" << TextAttribute::Reset;
         std::sort(m_relevantDirs.begin(), m_relevantDirs.end(),
             [](const RelevantDir &lhs, const RelevantDir &rhs) { return lhs.dirObj->displayName() < rhs.dirObj->displayName(); });
         std::for_each(m_relevantDirs.cbegin(), m_relevantDirs.cend(), bind(&Application::printDir, this, std::placeholders::_1));
@@ -632,7 +645,7 @@ void Application::printStatus(const ArgumentOccurrence &)
     if (!m_relevantDevs.empty()) {
         cout << TextAttribute::Bold << "Devices\n" << TextAttribute::Reset;
         std::sort(m_relevantDevs.begin(), m_relevantDevs.end(), [](const SyncthingDev *lhs, const SyncthingDev *rhs) {
-            const auto lhsIsOwn = lhs->status == SyncthingDevStatus::OwnDevice, rhsIsOwn = rhs->status == SyncthingDevStatus::OwnDevice;
+            const auto lhsIsOwn = lhs->status == SyncthingDevStatus::ThisDevice, rhsIsOwn = rhs->status == SyncthingDevStatus::ThisDevice;
             return lhsIsOwn != rhsIsOwn ? lhsIsOwn : lhs->displayName() < rhs->displayName();
         });
         std::for_each(m_relevantDevs.cbegin(), m_relevantDevs.cend(), bind(&Application::printDev, this, std::placeholders::_1));
@@ -650,7 +663,7 @@ void Application::printLog(const std::vector<SyncthingLogEntry> &logEntries)
         const auto when = entry.when.toUtf8();
         try {
             cout << DateTime::fromIsoStringLocal(when.data()).toString(DateTimeOutputFormat::DateAndTime, true);
-        } catch (const ConversionException &e) {
+        } catch (const ConversionException &) {
             cout << when.data();
         }
         cout << ':' << ' ' << entry.message.toLocal8Bit().data() << '\n';
@@ -930,46 +943,45 @@ void Application::waitForIdle(const ArgumentOccurrence &)
 {
     m_preventDisconnect = true;
 
-    // setup timer
-    QTimer idleTime;
+    // setup timer for handling minimum idle duration
+    auto idleTime = QTimer();
     idleTime.setSingleShot(true);
     idleTime.setInterval(m_idleDuration);
 
-    // define variable which is set to true if handleTimeout to indicate the idle state has persisted long enough
-    bool isLongEnoughIdle = false;
-
-    // define handler for timer timeout
-    function<void(void)> handleTimeout([this, &isLongEnoughIdle] {
+    // define event handlers
+    auto isLongEnoughIdle = false, dirsOrDevsChanged = true, newDirsOrDevs = true;
+    const auto handleStatusChange = [&dirsOrDevsChanged] { dirsOrDevsChanged = true; };
+    const auto handleNewDirsOrDevs = [&newDirsOrDevs] { newDirsOrDevs = true; };
+    const auto handleAllEventsProcessed = [this, &newDirsOrDevs, &dirsOrDevsChanged, &idleTime] {
+        if (newDirsOrDevs) {
+            findRelevantDirsAndDevs(OperationType::WaitForIdle);
+        }
+        if (newDirsOrDevs || dirsOrDevsChanged) {
+            if (!checkWhetherIdle()) {
+                idleTime.stop();
+                return;
+            }
+            if (!idleTime.isActive()) {
+                idleTime.start();
+            }
+        }
+        newDirsOrDevs = dirsOrDevsChanged = false;
+    };
+    const auto handleIdleTimer = [this, &isLongEnoughIdle] {
         if (checkWhetherIdle()) {
             isLongEnoughIdle = true;
         }
-    });
-
-    // define handler for dirStatusChanged/devStatusChanged
-    function<void(void)> handleStatusChange([this, &idleTime] {
-        if (!checkWhetherIdle()) {
-            idleTime.stop();
-            return;
-        }
-        if (!idleTime.isActive()) {
-            idleTime.start();
-        }
-    });
-
-    // define handler for newDirs/newDevices to call findRelevantDirsAndDevs() in that case
-    function<void(void)> handleNewDirsOrDevs([this, &handleStatusChange] {
-        findRelevantDirsAndDevs(OperationType::WaitForIdle);
-        handleStatusChange();
-    });
+    };
 
     // invoke handler manually because Syncthing could already be idling
-    handleNewDirsOrDevs();
+    handleAllEventsProcessed();
 
     waitForSignals(&noop, m_idleTimeout, signalInfo(&m_connection, &SyncthingConnection::dirStatusChanged, handleStatusChange, &isLongEnoughIdle),
         signalInfo(&m_connection, &SyncthingConnection::devStatusChanged, handleStatusChange, &isLongEnoughIdle),
         signalInfo(&m_connection, &SyncthingConnection::newDirs, handleNewDirsOrDevs, &isLongEnoughIdle),
         signalInfo(&m_connection, &SyncthingConnection::newDevices, handleNewDirsOrDevs, &isLongEnoughIdle),
-        signalInfo(&idleTime, &QTimer::timeout, handleTimeout, &isLongEnoughIdle));
+        signalInfo(&m_connection, &SyncthingConnection::allEventsProcessed, handleAllEventsProcessed, &isLongEnoughIdle),
+        signalInfo(&idleTime, &QTimer::timeout, handleIdleTimer, &isLongEnoughIdle));
 
     if (!isLongEnoughIdle) {
         cerr << Phrases::Warning << "Exiting after timeout" << Phrases::End << flush;
@@ -992,7 +1004,11 @@ bool Application::checkWhetherIdle() const
         switch (dev->status) {
         case SyncthingDevStatus::Unknown:
         case SyncthingDevStatus::Disconnected:
-        case SyncthingDevStatus::OwnDevice:
+            if (m_args.requireDevsConnected.isPresent()) {
+                return false;
+            }
+            break;
+        case SyncthingDevStatus::ThisDevice:
         case SyncthingDevStatus::Idle:
             break;
         default:
@@ -1039,12 +1055,12 @@ void Application::requestPausePwd(const ArgumentOccurrence &)
         return;
     }
     if (m_connection.pauseDirectories(QStringList(m_pwd.dirObj->id))) {
-        cerr << "Request pausing directory \"" << m_pwd.dirObj->path.toLocal8Bit().data() << "\" ..." << endl;
+        cerr << "Request pausing folder \"" << m_pwd.dirObj->path.toLocal8Bit().data() << "\" ..." << endl;
         connect(&m_connection, &SyncthingConnection::directoryPauseTriggered, this, &Application::handleResponse);
         m_preventDisconnect = true;
         m_expectedResponse = 1;
     } else {
-        cerr << "Directory \"" << m_pwd.dirObj->path.toLocal8Bit().data() << " already paused" << endl;
+        cerr << "Folder \"" << m_pwd.dirObj->path.toLocal8Bit().data() << " already paused" << endl;
         QCoreApplication::quit();
     }
 }
@@ -1055,13 +1071,13 @@ void Application::requestResumePwd(const ArgumentOccurrence &)
         return;
     }
     if (m_connection.resumeDirectories(QStringList(m_pwd.dirObj->id))) {
-        cerr << "Request resuming directory \"" << m_pwd.dirObj->path.toLocal8Bit().data() << "\" ..." << endl;
+        cerr << "Request resuming folder \"" << m_pwd.dirObj->path.toLocal8Bit().data() << "\" ..." << endl;
         connect(&m_connection, &SyncthingConnection::directoryResumeTriggered, this, &Application::handleResponse);
         m_preventDisconnect = true;
         m_expectedResponse = 1;
         return;
     } else {
-        cerr << "Directory \"" << m_pwd.dirObj->path.toLocal8Bit().data() << " not paused" << endl;
+        cerr << "Folder \"" << m_pwd.dirObj->path.toLocal8Bit().data() << " not paused" << endl;
         QCoreApplication::quit();
     }
 }
@@ -1073,7 +1089,10 @@ void Application::initDirCompletion(Argument &arg, const ArgumentOccurrence &)
         return;
     }
     // load config and wait for connected
-    loadConfig();
+    if (loadConfig()) {
+        return;
+    }
+    m_settings.requestTimeout = 5000; // avoid blocking shell for too long
     waitForConfig();
     // set directory IDs as completion values
     m_dirCompletion = m_connection.directoryIds().join(QChar(' ')).toUtf8();
@@ -1087,7 +1106,10 @@ void Application::initDevCompletion(Argument &arg, const ArgumentOccurrence &)
         return;
     }
     // load config and wait for connected
-    loadConfig();
+    if (loadConfig()) {
+        return;
+    }
+    m_settings.requestTimeout = 5000; // avoid blocking shell for too long
     waitForConfig();
     // set device IDs and names as completion values
     QStringList completionValues;
@@ -1111,7 +1133,7 @@ RelevantDir Application::findDirectory(const QString &dirIdentifier)
     // check whether the specified identifier is a known Syncthing directory or a relative path to an item in a
     // known Syncthing directory
     auto firstSlash = dirIdentifier.indexOf(QChar('/'));
-    relevantDir.dirObj = m_connection.findDirInfo(firstSlash >= 0 ? dirIdentifier.mid(0, firstSlash) : dirIdentifier, dummy);
+    relevantDir.dirObj = m_connection.findDirInfoConsideringLabels(firstSlash >= 0 ? dirIdentifier.mid(0, firstSlash) : dirIdentifier, dummy);
     if (relevantDir) {
         if (firstSlash >= 0) {
             relevantDir.subDir = dirIdentifier.mid(firstSlash + 1);
@@ -1126,7 +1148,7 @@ RelevantDir Application::findDirectory(const QString &dirIdentifier)
         return relevantDir;
     }
 
-    cerr << Phrases::Warning << "Specified directory \"" << dirIdentifier.toLocal8Bit().data() << "\" is no Syncthing directory (or not part of any)."
+    cerr << Phrases::Warning << "Specified folder \"" << dirIdentifier.toLocal8Bit().data() << "\" is no Syncthing folder (or not part of any)."
          << Phrases::End;
     return relevantDir;
 }
@@ -1135,7 +1157,7 @@ void RelevantDir::notifyAboutRescan() const
 {
     cerr << Phrases::Info;
     if (subDir.isEmpty()) {
-        cerr << "Request rescanning directory \"" << dirObj->path.toLocal8Bit().data() << "\" ...";
+        cerr << "Request rescanning folder \"" << dirObj->path.toLocal8Bit().data() << "\" ...";
     } else {
         cerr << "Request rescanning item \"" << subDir.toLocal8Bit().data() << "\" in directory \"" << dirObj->path.toLocal8Bit().data() << "\" ...";
     }
