@@ -4,6 +4,8 @@
 #include <syncthingconnector/syncthingservice.h>
 #include <syncthingconnector/utils.h>
 
+#include <syncthingmodel/syncthingicons.h>
+
 #include <syncthingwidgets/misc/direrrorsdialog.h>
 #include <syncthingwidgets/misc/internalerrorsdialog.h>
 #include <syncthingwidgets/misc/otherdialogs.h>
@@ -12,10 +14,9 @@
 #include <syncthingwidgets/settings/settingsdialog.h>
 #include <syncthingwidgets/settings/wizard.h>
 #include <syncthingwidgets/webview/webviewdialog.h>
-
-#include <syncthingmodel/syncthingicons.h>
-
-#include <syncthingconnector/utils.h>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+#include <syncthingwidgets/misc/syncthinglauncher.h>
+#endif
 
 #include "resources/config.h"
 #include "resources/qtconfig.h"
@@ -362,10 +363,21 @@ QString SyncthingApplet::substituteTilde(const QString &path) const
     return Data::substituteTilde(path, m_connection.tilde(), m_connection.pathSeparator());
 }
 
+bool SyncthingApplet::areWipFeaturesEnabled() const
+{
+    return Settings::values().enableWipFeatures;
+}
+
 void SyncthingApplet::showSettingsDlg()
 {
     if (!m_settingsDlg) {
         m_settingsDlg = new SettingsDialog(*this);
+        // create a launcher as its monitoring of whether the network is metered is required by the connection settings
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+        if (!SyncthingLauncher::mainInstance()) {
+            SyncthingLauncher::setMainInstance(new SyncthingLauncher(m_settingsDlg));
+        }
+#endif
         // show wizard when requested
         connect(m_settingsDlg, &SettingsDialog::wizardRequested, this, &SyncthingApplet::showWizard);
         // ensure settings take effect when applied
@@ -510,6 +522,19 @@ void SyncthingApplet::showDirectoryErrors(const QString &dirId)
     dlg->show();
 }
 
+void SyncthingApplet::browseRemoteFiles(const QString &dirId)
+{
+    auto row = 0;
+    auto *const dir = m_connection.findDirInfo(dirId, row);
+    if (!dir) {
+        return;
+    }
+    auto *const dlg = QtGui::browseRemoteFilesDialog(m_connection, *dir);
+    dlg->resize(600, 500);
+    centerWidget(dlg);
+    dlg->show();
+}
+
 void SyncthingApplet::copyToClipboard(const QString &text)
 {
     QGuiApplication::clipboard()->setText(text);
@@ -644,7 +669,7 @@ void SyncthingApplet::applySettings(int changeConnectionIndex)
     const KConfigGroup config = this->config();
     const auto &settings = Settings::values();
 
-    // apply notifiction settings
+    // apply notification settings
     settings.apply(m_notifier);
 
     // apply appearance settings
