@@ -14,6 +14,7 @@
 
 #include <QAuthenticator>
 #include <QDir>
+#include <QFileInfo>
 #include <QHostAddress>
 #include <QJsonArray>
 #include <QJsonDocument>
@@ -24,6 +25,11 @@
 #include <QStringBuilder>
 #include <QTimer>
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 4, 0))
+#include <QNetworkInformation>
+#define SYNCTHINGCONNECTION_SUPPORT_METERED
+#endif
+
 #include <iostream>
 #include <utility>
 
@@ -107,6 +113,10 @@ SyncthingConnection::SyncthingConnection(
     , m_dirStatsAltered(false)
     , m_recordFileChanges(false)
     , m_useDeprecatedRoutes(true)
+    , m_pausingOnMeteredConnection(false)
+#ifdef SYNCTHINGCONNECTION_SUPPORT_METERED
+    , m_handlingMeteredConnectionInitialized(false)
+#endif
 {
     m_trafficPollTimer.setInterval(SyncthingConnectionSettings::defaultTrafficPollInterval);
     m_trafficPollTimer.setTimerType(Qt::VeryCoarseTimer);
@@ -247,6 +257,60 @@ void SyncthingConnection::disablePolling()
     setErrorsPollInterval(0);
 }
 
+/*!
+ * \brief Sets whether to pause all devices on metered connections.
+ */
+void SyncthingConnection::setPausingOnMeteredConnection(bool pausingOnMeteredConnection)
+{
+    if (m_pausingOnMeteredConnection != pausingOnMeteredConnection) {
+        if ((m_pausingOnMeteredConnection = pausingOnMeteredConnection)) {
+            // initialize handling of metered connections
+#ifdef SYNCTHINGCONNECTION_SUPPORT_METERED
+            if (!m_handlingMeteredConnectionInitialized) {
+                QNetworkInformation::loadBackendByFeatures(QNetworkInformation::Feature::Metered);
+                if (const auto *const networkInformation = QNetworkInformation::instance()) {
+                    QObject::connect(networkInformation, &QNetworkInformation::isMeteredChanged, this, &SyncthingConnection::handleMeteredConnection);
+                }
+            }
+#endif
+        }
+        if (m_hasConfig) {
+            handleMeteredConnection();
+        }
+    }
+}
+
+/*!
+ * \brief Ensures that devices are paused/resumed depending on whether the network connection is metered.
+ */
+void SyncthingConnection::handleMeteredConnection()
+{
+#ifdef SYNCTHINGCONNECTION_SUPPORT_METERED
+    const auto *const networkInformation = QNetworkInformation::instance();
+    if (!networkInformation || !networkInformation->supports(QNetworkInformation::Feature::Metered)) {
+        return;
+    }
+    if (networkInformation->isMetered() && m_pausingOnMeteredConnection) {
+        auto hasDevicesToPause = false;
+        m_devsPausedDueToMeteredConnection.reserve(static_cast<qsizetype>(m_devs.size()));
+        for (const auto &device : m_devs) {
+            if (!device.paused && device.status != SyncthingDevStatus::ThisDevice) {
+                if (!m_devsPausedDueToMeteredConnection.contains(device.id)) {
+                    m_devsPausedDueToMeteredConnection << device.id;
+                    hasDevicesToPause = true;
+                }
+            }
+        }
+        if (hasDevicesToPause) {
+            pauseResumeDevice(m_devsPausedDueToMeteredConnection, true, true);
+        }
+    } else {
+        pauseResumeDevice(m_devsPausedDueToMeteredConnection, false, true);
+        m_devsPausedDueToMeteredConnection.clear();
+    }
+#endif
+}
+
 /*!
  * \brief Connects asynchronously to Syncthing. Does nothing if already connected.
  *
@@ -444,6 +508,7 @@ void SyncthingConnection::continueReconnecting()
     m_hasDiskEvents = false;
     m_dirs.clear();
     m_devs.clear();
+    m_devsPausedDueToMeteredConnection.clear();
     m_lastConnectionsUpdateEvent = 0;
     m_lastConnectionsUpdateTime = DateTime();
     m_lastFileEvent = 0;
@@ -776,6 +841,10 @@ void SyncthingConnection::continueConnecting()
  *  - Loading the certificate is only possible if the connection object is configured
  *    to connect to the locally running Syncthing instance. Otherwise this method will
  *    only do the cleanup of previous certificates but not emit any errors.
+ *  - This function uses m_certificatePath which is set by applySettings() if the user
+ *    specified a certificate path manually. Otherwise the path is detected automatically
+ *    and stored in m_dynamicallyDeterminedCertificatePath so the certificate path is
+ *    known in handleSslErrors().
  * \returns Returns whether a certificate could be loaded.
  */
 bool SyncthingConnection::loadSelfSignedCertificate(const QUrl &url)
@@ -795,7 +864,9 @@ bool SyncthingConnection::loadSelfSignedCertificate(const QUrl &url)
     }
 
     // find cert
-    const auto certPath = !m_configDir.isEmpty() ? (m_configDir + QStringLiteral("/https-cert.pem")) : SyncthingConfig::locateHttpsCertificate();
+    const auto certPath = !m_certificatePath.isEmpty()
+        ? m_certificatePath
+        : (!m_configDir.isEmpty() ? (m_configDir + QStringLiteral("/https-cert.pem")) : SyncthingConfig::locateHttpsCertificate());
     if (certPath.isEmpty()) {
         emit error(tr("Unable to locate certificate used by Syncthing."), SyncthingErrorCategory::OverallConnection, QNetworkReply::NoError);
         return false;
@@ -807,13 +878,33 @@ bool SyncthingConnection::loadSelfSignedCertificate(const QUrl &url)
         return false;
     }
     m_expectedSslErrors = SyncthingConnectionSettings::compileSslErrors(certs.at(0));
+    // keep track of the dynamically determined certificate path for handleSslErrors()
+    if (m_certificatePath.isEmpty()) {
+        m_dynamicallyDeterminedCertificatePath = certPath;
+        m_certificateLastModified = QFileInfo(certPath).lastModified();
+    }
     return true;
 }
 
+/*!
+ * \brief Clears the self-signed certificate that might be loaded via loadSelfSignedCertificate().
+ * \remarks This function mainly exists to ease testing; one normally doesn't need to invoke it explicitly.
+ */
+void SyncthingConnection::clearSelfSignedCertificate()
+{
+    m_expectedSslErrors.clear();
+    m_certificatePath.clear();
+    m_dynamicallyDeterminedCertificatePath.clear();
+    m_certificateLastModified = QDateTime();
+}
+
 /*!
  * \brief Applies the specified configuration.
  * \remarks
- * - The expected SSL errors of the specified configuration are updated accordingly.
+ * - The expected SSL errors are taken from the specified \a connectionSettings. If empty, this
+ *   function attempts to load expected SSL errors automatically as needed/possible via
+ *   loadSelfSignedCertificate(). It then writes back those SSL errors to \a connectionSettings.
+ *   This way \a connectionSettings can act as a cache for SSL exceptions.
  * - The configuration is not used instantly. It will be used on the next reconnect.
  * \returns Returns whether at least one property requiring a reconnect to take effect has changed.
  * \sa reconnect()
@@ -838,6 +929,8 @@ bool SyncthingConnection::applySettings(SyncthingConnectionSettings &connectionS
         }
         reconnectRequired = true;
     }
+    m_certificatePath = connectionSettings.httpsCertPath;
+    m_certificateLastModified = connectionSettings.httpCertLastModified;
     if (connectionSettings.expectedSslErrors.isEmpty()) {
         const bool previouslyHadExpectedSslErrors = !expectedSslErrors().isEmpty();
         const bool ok = loadSelfSignedCertificate();
@@ -857,6 +950,7 @@ bool SyncthingConnection::applySettings(SyncthingConnectionSettings &connectionS
     setRequestTimeout(connectionSettings.requestTimeout);
     setLongPollingTimeout(connectionSettings.longPollingTimeout);
     setStatusComputionFlags(connectionSettings.statusComputionFlags);
+    setPausingOnMeteredConnection(connectionSettings.pauseOnMeteredConnection);
 
     return reconnectRequired;
 }
