@@ -9,6 +9,7 @@
 #include <c++utilities/misc/flagenumclass.h>
 
 #include <QByteArray>
+#include <QDateTime>
 #include <QJsonObject>
 #include <QList>
 #include <QNetworkRequest>
@@ -16,6 +17,11 @@
 #include <QSslError>
 #include <QTimer>
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 3, 0))
+#include <QNetworkInformation>
+#define SYNCTHINGCONNECTION_SUPPORT_METERED
+#endif
+
 #include <cstdint>
 #include <functional>
 #include <limits>
@@ -47,6 +53,21 @@ struct LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingLogEntry {
     QString message;
 };
 
+enum class SyncthingItemType { Unknown, File, Directory };
+
+struct LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingItem {
+    QString name;
+    CppUtilities::DateTime modificationTime;
+    std::size_t size = std::size_t();
+    SyncthingItemType type = SyncthingItemType::Unknown;
+    std::vector<SyncthingItem> children;
+    SyncthingItem *parent = nullptr; // not populated but might be set as needed (take care in case the pointer gets invalidated)
+    std::size_t index = std::size_t();
+    int level = 0; // the level of nesting, does *not* include levels of the prefix
+    bool childrenPopulated = false; // populated depending on requested level
+    bool checked = false; // not populated but might be set to flag an item for some mass-action
+};
+
 class LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConnection : public QObject {
     friend ConnectionTests;
     friend MiscTests;
@@ -91,6 +112,7 @@ class LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConnection : public QObject {
     Q_PROPERTY(QStringList deviceIds READ deviceIds)
     Q_PROPERTY(QJsonObject rawConfig READ rawConfig NOTIFY newConfig)
     Q_PROPERTY(bool useDeprecatedRoutes READ isUsingDeprecatedRoutes WRITE setUseDeprecatedRoutes)
+    Q_PROPERTY(bool pausingOnMeteredConnection READ isPausingOnMeteredConnection WRITE setPausingOnMeteredConnection)
 
 public:
     explicit SyncthingConnection(const QString &syncthingUrl = QStringLiteral("http://localhost:8080"), const QByteArray &apiKey = QByteArray(),
@@ -144,6 +166,8 @@ public:
     void setRequestTimeout(int requestTimeout);
     int longPollingTimeout() const;
     void setLongPollingTimeout(int longPollingTimeout);
+    bool isPausingOnMeteredConnection() const;
+    void setPausingOnMeteredConnection(bool pausingOnMeteredConnection);
 
     // getter for information retrieved from Syncthing
     const QString &configDir() const;
@@ -181,6 +205,7 @@ public:
 
 public Q_SLOTS:
     bool loadSelfSignedCertificate(const QUrl &url = QUrl());
+    void clearSelfSignedCertificate();
     bool applySettings(Data::SyncthingConnectionSettings &connectionSettings);
 
     // methods to initiate/close connection
@@ -230,6 +255,11 @@ public Q_SLOTS:
     void postConfigFromJsonObject(const QJsonObject &rawConfig);
     void postConfigFromByteArray(const QByteArray &rawConfig);
 
+public:
+    // methods to GET or POST information from/to Syncthing (non-slots)
+    QMetaObject::Connection browse(
+        const QString &dirId, const QString &prefix, int level, std::function<void(std::vector<SyncthingItem> &&)> &&callback);
+
 Q_SIGNALS:
     void newConfig(const QJsonObject &rawConfig);
     void newDirs(const std::vector<SyncthingDir> &dirs);
@@ -338,12 +368,13 @@ private Q_SLOTS:
     void handleAdditionalRequestCanceled();
     void handleSslErrors(const QList<QSslError> &errors);
     void handleRedirection(const QUrl &url);
+    void handleMeteredConnection();
     void recalculateStatus();
-    QString configPath() const;
-    QByteArray changeConfigVerb() const;
-    QString folderErrorsPath() const;
 
 private:
+    // handler to evaluate results from request...() methods
+    void readBrowse(const QString &dirId, int levels, std::function<void(std::vector<SyncthingItem> &&)> &&callback);
+
     // internal helper methods
     struct Reply {
         QNetworkReply *reply;
@@ -357,12 +388,15 @@ private:
     Reply prepareReply(QNetworkReply *&expectedReply, bool readData = true, bool handleAborting = true);
     Reply prepareReply(QList<QNetworkReply *> &expectedReplies, bool readData = true, bool handleAborting = true);
     Reply handleReply(QNetworkReply *reply, bool readData, bool handleAborting);
-    bool pauseResumeDevice(const QStringList &devIds, bool paused);
+    bool pauseResumeDevice(const QStringList &devIds, bool paused, bool dueToMetered = false);
     bool pauseResumeDirectory(const QStringList &dirIds, bool paused);
     SyncthingDir *addDirInfo(std::vector<SyncthingDir> &dirs, const QString &dirId);
     SyncthingDev *addDevInfo(std::vector<SyncthingDev> &devs, const QString &devId);
     CppUtilities::DateTime parseTimeStamp(const QJsonValue &jsonValue, const QString &context,
         CppUtilities::DateTime defaultValue = CppUtilities::DateTime(), bool greaterThanEpoch = false);
+    QString configPath() const;
+    QByteArray changeConfigVerb() const;
+    QString folderErrorsPath() const;
 
     QString m_syncthingUrl;
     QByteArray m_apiKey;
@@ -413,6 +447,7 @@ private:
     bool m_hasDiskEvents;
     std::vector<SyncthingDir> m_dirs;
     std::vector<SyncthingDev> m_devs;
+    QStringList m_devsPausedDueToMeteredConnection;
     SyncthingEventId m_lastConnectionsUpdateEvent;
     CppUtilities::DateTime m_lastConnectionsUpdateTime;
     SyncthingEventId m_lastFileEvent = 0;
@@ -422,12 +457,19 @@ private:
     QString m_lastFileName;
     QString m_syncthingVersion;
     bool m_lastFileDeleted;
+    QString m_certificatePath;
+    QString m_dynamicallyDeterminedCertificatePath;
+    QDateTime m_certificateLastModified;
     QList<QSslError> m_expectedSslErrors;
     QSslCertificate m_certFromLastSslError;
     QJsonObject m_rawConfig;
     bool m_dirStatsAltered;
     bool m_recordFileChanges;
     bool m_useDeprecatedRoutes;
+    bool m_pausingOnMeteredConnection;
+#ifdef SYNCTHINGCONNECTION_SUPPORT_METERED
+    bool m_handlingMeteredConnectionInitialized;
+#endif
 };
 
 /*!
@@ -763,6 +805,14 @@ inline void SyncthingConnection::setLongPollingTimeout(int longPollingTimeout)
     m_longPollingTimeout = longPollingTimeout;
 }
 
+/*!
+ * \brief Returns whether to pause all devices on metered connections.
+ */
+inline bool SyncthingConnection::isPausingOnMeteredConnection() const
+{
+    return m_pausingOnMeteredConnection;
+}
+
 /*!
  * \brief Returns what information is considered to compute the overall status returned by status().
  */
