@@ -30,6 +30,18 @@ namespace Data {
 
 // helper to create QNetworkRequest
 
+/*!
+ * \brief Formats the specified \a value so it can be passed to QUrlQuery::addQueryItem().
+ * \remarks
+ * The function QUrlQuery::addQueryItem() does *not* treat spaces and plus signs as the same,
+ * ike HTML forms and Syncthing do. So it is required to use QUrl::toPercentEncoding() as Syncthing
+ * would otherwise misinterpret plus signs as spaces.
+ */
+inline QString formatQueryItem(const QString &value)
+{
+    return QString::fromUtf8(QUrl::toPercentEncoding(value));
+}
+
 /*!
  * \brief Prepares a request for the specified \a path and \a query.
  */
@@ -146,7 +158,14 @@ static QString certText(const QSslCertificate &cert)
 /// \endcond
 
 /*!
- * \brief Handles SSL errors of replies; just for logging purposes at this point.
+ * \brief Handles SSL errors of replies.
+ * \remarks
+ * - Ignores expected errors which are usually assigned via applySettings() or loadSelfSignedCertificate() to handle a self-signed
+ *   certificate.
+ * - If expected errors have previously been assigned to handle a self-signed certificate this function attempts to reload the
+ *   certificate via loadSelfSignedCertificate() if it appears to be re-generated. This is done because Syncthing might re-generate
+ *   the certificate if it will expire soon (indicated by the log message "Loading HTTPS certificate: certificate will soon expire"
+ *   followed by "Creating new HTTPS certificate").
  */
 void SyncthingConnection::handleSslErrors(const QList<QSslError> &errors)
 {
@@ -162,6 +181,20 @@ void SyncthingConnection::handleSslErrors(const QList<QSslError> &errors)
             continue;
         }
 
+        // check whether the certificate has changed and reload it before emitting error
+        if (const auto &certPath = m_certificatePath.isEmpty() ? m_dynamicallyDeterminedCertificatePath : m_certificatePath;
+            !certPath.isEmpty() && m_certificateLastModified.isValid()) {
+            if (const auto lastModified = QFileInfo(certPath).lastModified(); lastModified > m_certificateLastModified) {
+                if (const auto ok = loadSelfSignedCertificate(); ok && !m_certificatePath.isEmpty()) {
+                    m_certificateLastModified = lastModified;
+                }
+                // re-check whether error is expected after reloading and skip it accordingly
+                if (m_expectedSslErrors.contains(error)) {
+                    continue;
+                }
+            }
+        }
+
         // handle the error by emitting the error signal with all the details including the certificate
         // note: Of course the failing request would cause a QNetworkReply::SslHandshakeFailedError anyways. However,
         //       at this point the concrete SSL error with the certificate is not accessible anymore.
@@ -305,16 +338,15 @@ bool SyncthingConnection::resumeAllDevs()
 /*!
  * \brief Internally used to pause/resume directories.
  * \returns Returns whether a request has been made.
- * \remarks This might currently result in errors caused by Syncthing not
- *          handling E notation correctly when using Qt < 5.9:
- *          https://github.com/syncthing/syncthing/issues/4001
+ * \remarks This might result in errors caused by Syncthing not handling E notation correctly when using Qt < 5.9,
+ *          see https://github.com/syncthing/syncthing/issues/4001.
  */
-bool SyncthingConnection::pauseResumeDevice(const QStringList &devIds, bool paused)
+bool SyncthingConnection::pauseResumeDevice(const QStringList &devIds, bool paused, bool dueToMetered)
 {
     if (devIds.isEmpty()) {
         return false;
     }
-    if (!isConnected()) {
+    if (!m_hasConfig) {
         emit error(tr("Unable to pause/resume a devices when not connected"), SyncthingErrorCategory::SpecificRequest, QNetworkReply::NoError);
         return false;
     }
@@ -330,6 +362,13 @@ bool SyncthingConnection::pauseResumeDevice(const QStringList &devIds, bool paus
     reply->setProperty("devIds", devIds);
     reply->setProperty("resume", !paused);
     QObject::connect(reply, &QNetworkReply::finished, this, &SyncthingConnection::readDevPauseResume);
+
+    // avoid considering manually paused or resumed devices when the network connection is no longer metered
+    if (!dueToMetered && !m_devsPausedDueToMeteredConnection.isEmpty()) {
+        for (const auto &devId : devIds) {
+            m_devsPausedDueToMeteredConnection.removeAll(devId);
+        }
+    }
     return true;
 }
 
@@ -497,9 +536,9 @@ void SyncthingConnection::rescan(const QString &dirId, const QString &relpath)
     }
 
     auto query = QUrlQuery();
-    query.addQueryItem(QStringLiteral("folder"), dirId);
+    query.addQueryItem(QStringLiteral("folder"), formatQueryItem(dirId));
     if (!relpath.isEmpty()) {
-        query.addQueryItem(QStringLiteral("sub"), relpath);
+        query.addQueryItem(QStringLiteral("sub"), formatQueryItem(relpath));
     }
     QNetworkReply *reply = postData(QStringLiteral("db/scan"), query);
     reply->setProperty("dirId", dirId);
@@ -761,6 +800,9 @@ void SyncthingConnection::readDevs(const QJsonArray &devs)
 
     m_devs.swap(newDevs);
     emit this->newDevices(m_devs);
+    if (m_pausingOnMeteredConnection) {
+        handleMeteredConnection();
+    }
 }
 
 // status of Syncthing (own ID, startup time)
@@ -1097,7 +1139,7 @@ void SyncthingConnection::readDirStatistics()
 void SyncthingConnection::requestDirStatus(const QString &dirId)
 {
     auto query = QUrlQuery();
-    query.addQueryItem(QStringLiteral("folder"), dirId);
+    query.addQueryItem(QStringLiteral("folder"), formatQueryItem(dirId));
     auto *const reply = requestData(QStringLiteral("db/status"), query);
     reply->setProperty("dirId", dirId);
     reply->setProperty("lastEventId", m_lastEventId);
@@ -1157,7 +1199,7 @@ void SyncthingConnection::readDirStatus()
 void SyncthingConnection::requestDirPullErrors(const QString &dirId, int page, int perPage)
 {
     auto query = QUrlQuery();
-    query.addQueryItem(QStringLiteral("folder"), dirId);
+    query.addQueryItem(QStringLiteral("folder"), formatQueryItem(dirId));
     if (page > 0 && perPage > 0) {
         query.addQueryItem(QStringLiteral("page"), QString::number(page));
         query.addQueryItem(QStringLiteral("perpage"), QString::number(perPage));
@@ -1213,8 +1255,8 @@ void SyncthingConnection::readDirPullErrors()
 void SyncthingConnection::requestCompletion(const QString &devId, const QString &dirId)
 {
     auto query = QUrlQuery();
-    query.addQueryItem(QStringLiteral("device"), devId);
-    query.addQueryItem(QStringLiteral("folder"), dirId);
+    query.addQueryItem(QStringLiteral("device"), formatQueryItem(devId));
+    query.addQueryItem(QStringLiteral("folder"), formatQueryItem(dirId));
     auto *const reply = requestData(QStringLiteral("db/completion"), query);
     reply->setProperty("devId", devId);
     reply->setProperty("dirId", dirId);
@@ -1397,7 +1439,7 @@ void SyncthingConnection::readVersion()
 void SyncthingConnection::requestQrCode(const QString &text)
 {
     auto query = QUrlQuery();
-    query.addQueryItem(QStringLiteral("text"), text);
+    query.addQueryItem(QStringLiteral("text"), formatQueryItem(text));
     QNetworkReply *reply = requestData(QStringLiteral("/qr/"), query, false);
     reply->setProperty("qrText", text);
     QObject::connect(reply, &QNetworkReply::finished, this, &SyncthingConnection::readQrCode);
@@ -1483,7 +1525,7 @@ void SyncthingConnection::readLog()
 void SyncthingConnection::requestOverride(const QString &dirId)
 {
     auto query = QUrlQuery();
-    query.addQueryItem(QStringLiteral("folder"), dirId);
+    query.addQueryItem(QStringLiteral("folder"), formatQueryItem(dirId));
     auto *const reply = postData(QStringLiteral("db/override"), query);
     reply->setProperty("dirId", dirId);
     QObject::connect(reply, &QNetworkReply::finished, this, &SyncthingConnection::readOverride, Qt::QueuedConnection);
@@ -1516,7 +1558,7 @@ void SyncthingConnection::readOverride()
 void SyncthingConnection::requestRevert(const QString &dirId)
 {
     auto query = QUrlQuery();
-    query.addQueryItem(QStringLiteral("folder"), dirId);
+    query.addQueryItem(QStringLiteral("folder"), formatQueryItem(dirId));
     auto *const reply = postData(QStringLiteral("db/revert"), query);
     reply->setProperty("dirId", dirId);
     QObject::connect(reply, &QNetworkReply::finished, this, &SyncthingConnection::readRevert, Qt::QueuedConnection);
@@ -1540,6 +1582,96 @@ void SyncthingConnection::readRevert()
     }
 }
 
+/*!
+ * \brief Lists items in the directory with the specified \a dirId down to \a levels (or fully if \a levels is 0) as of \a prefix.
+ * \sa https://docs.syncthing.net/rest/db-browse-get.html
+ * \remarks
+ * In contrast to other functions, this one uses a \a callback to return results (instead of a signal). This makes it easier to
+ * consume results of a specific request. Errors are still reported via the error() signal so there's no extra error handling
+ * required. Note that \a callback is *not* invoked in the error case.
+ */
+QMetaObject::Connection SyncthingConnection::browse(
+    const QString &dirId, const QString &prefix, int levels, std::function<void(std::vector<SyncthingItem> &&)> &&callback)
+{
+    auto query = QUrlQuery();
+    query.addQueryItem(QStringLiteral("folder"), formatQueryItem(dirId));
+    if (!prefix.isEmpty()) {
+        query.addQueryItem(QStringLiteral("prefix"), formatQueryItem(prefix));
+    }
+    if (levels > 0) {
+        query.addQueryItem(QStringLiteral("levels"), QString::number(levels));
+    }
+    return QObject::connect(
+        requestData(QStringLiteral("db/browse"), query), &QNetworkReply::finished, this,
+        [this, id = dirId, l = levels, cb = std::move(callback)]() mutable { readBrowse(id, l, std::move(cb)); }, Qt::QueuedConnection);
+}
+
+/// \cond
+static void readSyncthingItems(const QJsonArray &array, std::vector<SyncthingItem> &into, int level, int levels)
+{
+    into.reserve(static_cast<std::size_t>(array.size()));
+    for (const auto &jsonItem : array) {
+        if (!jsonItem.isObject()) {
+            continue;
+        }
+        const auto jsonItemObj = jsonItem.toObject();
+        const auto type = jsonItemObj.value(QLatin1String("type")).toString();
+        const auto index = into.size();
+        const auto children = jsonItemObj.value(QLatin1String("children"));
+        auto &item = into.emplace_back();
+        item.name = jsonItemObj.value(QLatin1String("name")).toString();
+        item.modificationTime = CppUtilities::DateTime::fromIsoStringGmt(jsonItemObj.value(QLatin1String("modTime")).toString().toUtf8().data());
+        item.size = static_cast<std::size_t>(jsonItemObj
+                                                 .value(QLatin1String("size"))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+                                                 .toInteger()
+#else
+                                                 .toDouble()
+#endif
+        );
+        item.index = index;
+        item.level = level;
+        if (type == QLatin1String("FILE_INFO_TYPE_FILE")) {
+            item.type = SyncthingItemType::File;
+        } else if (type == QLatin1String("FILE_INFO_TYPE_DIRECTORY")) {
+            item.type = SyncthingItemType::Directory;
+        }
+        readSyncthingItems(children.toArray(), item.children, level + 1, levels);
+        item.childrenPopulated = !levels || level < levels;
+    }
+}
+/// \endcond
+
+/*!
+ * \brief Reads the response of browse() and reports results via the specified \a callback or emits error() in case of an error.
+ */
+void SyncthingConnection::readBrowse(const QString &dirId, int levels, std::function<void(std::vector<SyncthingItem> &&)> &&callback)
+{
+    auto const [reply, response] = prepareReply();
+    if (!reply) {
+        return;
+    }
+    auto items = std::vector<SyncthingItem>();
+    switch (reply->error()) {
+    case QNetworkReply::NoError: {
+        auto jsonError = QJsonParseError();
+        const auto replyDoc = QJsonDocument::fromJson(response, &jsonError);
+        if (jsonError.error != QJsonParseError::NoError) {
+            emit error(tr("Unable to parse response for browsing \"%1\": ").arg(dirId) + jsonError.errorString(), SyncthingErrorCategory::Parsing,
+                QNetworkReply::NoError);
+            return;
+        }
+        readSyncthingItems(replyDoc.array(), items, 0, levels);
+        if (callback) {
+            callback(std::move(items));
+        }
+        break;
+    }
+    default:
+        emitError(tr("Unable to browse \"%1\": ").arg(dirId), SyncthingErrorCategory::SpecificRequest, reply);
+    }
+}
+
 // post config
 
 /*!
