@@ -4,259 +4,269 @@
 <context>
     <name>Data::SyncthingConnection</name>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="318"/>
+        <location filename="../syncthingconnection_requests.cpp" line="350"/>
         <source>Unable to pause/resume a devices when not connected</source>
         <translation>未连接时无法暂停/恢复设备</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="359"/>
+        <location filename="../syncthingconnection_requests.cpp" line="398"/>
         <source>Unable to request device pause/resume: </source>
         <translation>无法请求设备暂停/恢复： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="426"/>
+        <location filename="../syncthingconnection_requests.cpp" line="465"/>
         <source>Unable to pause/resume a folders when not connected</source>
         <translation>未连接时无法暂停/恢复目录</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="463"/>
+        <location filename="../syncthingconnection_requests.cpp" line="502"/>
         <source>Unable to request folder pause/resume: </source>
         <translation>无法请求目录暂停/恢复： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="494"/>
+        <location filename="../syncthingconnection_requests.cpp" line="533"/>
         <source>Unable to rescan: No folder ID specified.</source>
         <translation>无法重新扫描：未指定目录 ID。</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="524"/>
+        <location filename="../syncthingconnection_requests.cpp" line="563"/>
         <source>Unable to request rescan: </source>
         <translation>无法请求重新扫描： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="555"/>
+        <location filename="../syncthingconnection_requests.cpp" line="594"/>
         <source>Unable to request restart: </source>
         <translation>无法请求重启： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="584"/>
+        <location filename="../syncthingconnection_requests.cpp" line="623"/>
         <source>Unable to request shutdown: </source>
         <translation>无法请求关闭： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="615"/>
+        <location filename="../syncthingconnection_requests.cpp" line="654"/>
         <source>Unable to request clearing errors: </source>
         <translation>无法请求清除错误： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="649"/>
+        <location filename="../syncthingconnection_requests.cpp" line="688"/>
         <source>Unable to parse Syncthing config: </source>
         <translation>无法解析 Syncthing 配置： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="671"/>
+        <location filename="../syncthingconnection_requests.cpp" line="710"/>
         <source>Unable to request Syncthing config: </source>
         <translation>无法请求 Syncthing 配置： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="797"/>
+        <location filename="../syncthingconnection_requests.cpp" line="839"/>
         <source>Unable to parse Syncthing status: </source>
         <translation>无法解析 Syncthing 状态： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="816"/>
+        <location filename="../syncthingconnection_requests.cpp" line="858"/>
         <source>Unable to request Syncthing status: </source>
         <translation>无法请求 Syncthing 状态： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="864"/>
+        <location filename="../syncthingconnection_requests.cpp" line="906"/>
         <source>Unable to parse connections: </source>
         <translation>无法解析连接： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="941"/>
+        <location filename="../syncthingconnection_requests.cpp" line="983"/>
         <source>Unable to request connections: </source>
         <translation>无法请求连接： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="979"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1021"/>
         <source>Unable to parse errors: </source>
         <translation>无法解析错误： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1007"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1049"/>
         <source>Unable to request errors: </source>
         <translation>无法请求错误： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1039"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1081"/>
         <source>Unable to parse folder statistics: </source>
         <translation>无法解析目录统计信息： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1090"/>
-        <location filename="../syncthingconnection_requests.cpp" line="1148"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1132"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1190"/>
         <source>Unable to request folder statistics: </source>
         <translation>无法请求目录统计信息： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1133"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1175"/>
         <source>Unable to parse status for folder %1: </source>
         <translation>无法解析目录 %1 的状态： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1196"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1238"/>
         <source>Unable to parse pull errors for folder %1: </source>
         <translation>无法解析目录 %1 的拉取错误： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1206"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1248"/>
         <source>Unable to request pull errors for folder %1: </source>
         <translation>无法请求目录 %1 的拉取错误： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1272"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1314"/>
         <source>Unable to parse completion for device/folder %1/%2: </source>
         <translation>无法解析设备/目录 %1/%2 的完成情况： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1287"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1329"/>
         <source>Unable to request completion for device/folder %1/%2: </source>
         <translation>无法请求设备/目录 %1/%2 的完成情况： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1319"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1361"/>
         <source>Unable to parse device statistics: </source>
         <translation>无法解析设备统计数据： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1346"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1388"/>
         <source>Unable to request device statistics: </source>
         <translation>无法请求设备统计数据： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1374"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1416"/>
         <source>Unable to parse version: </source>
         <translation>无法解析版本： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1388"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1430"/>
         <source>Unable to request version: </source>
         <translation>无法请求版本： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1423"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1465"/>
         <source>Unable to request QR-Code: </source>
         <translation>无法请求二维码： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1456"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1498"/>
         <source>Unable to parse Syncthing log: </source>
         <translation>无法解析 Syncthing 日志： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1473"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1515"/>
         <source>Unable to request Syncthing log: </source>
         <translation>无法请求 Syncthing 日志： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1506"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1548"/>
         <source>Unable to request directory override: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1539"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1581"/>
         <source>Unable to request directory revert: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1579"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1660"/>
+        <source>Unable to parse response for browsing &quot;%1&quot;: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingconnection_requests.cpp" line="1674"/>
+        <source>Unable to browse &quot;%1&quot;: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingconnection_requests.cpp" line="1718"/>
         <source>Unable to post config: </source>
         <translation>无法发布日志： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1755"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1894"/>
         <source>Unable to parse Syncthing events: </source>
         <translation>无法解析 Syncthing 事件： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1782"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1921"/>
         <source>Unable to request Syncthing events: </source>
         <translation>无法请求 Syncthing 事件： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="2363"/>
+        <location filename="../syncthingconnection_requests.cpp" line="2502"/>
         <source>Unable to parse disk events: </source>
         <translation>无法解析磁盘事件： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="2386"/>
+        <location filename="../syncthingconnection_requests.cpp" line="2525"/>
         <source>Unable to request disk events: </source>
         <translation>无法请求磁盘事件： </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="165"/>
+        <location filename="../syncthingconnection.cpp" line="175"/>
         <source>disconnected</source>
         <translation>已断线</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="167"/>
+        <location filename="../syncthingconnection.cpp" line="177"/>
         <source>reconnecting</source>
         <translation>重连中</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="169"/>
+        <location filename="../syncthingconnection.cpp" line="179"/>
         <source>connected</source>
         <translation>已连接</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="171"/>
+        <location filename="../syncthingconnection.cpp" line="181"/>
         <source>connected, scanning</source>
         <translation>已连接，扫描中</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="173"/>
+        <location filename="../syncthingconnection.cpp" line="183"/>
         <source>connected, paused</source>
         <translation>已连接，已暂停</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="175"/>
+        <location filename="../syncthingconnection.cpp" line="185"/>
         <source>connected, synchronizing</source>
         <translation>已连接，同步中</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="177"/>
+        <location filename="../syncthingconnection.cpp" line="187"/>
         <source>connected, remote not in sync</source>
         <translation>已连接，远程未同步</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="179"/>
+        <location filename="../syncthingconnection.cpp" line="189"/>
         <source>unknown</source>
         <translation>未知</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="276"/>
-        <location filename="../syncthingconnection.cpp" line="465"/>
+        <location filename="../syncthingconnection.cpp" line="340"/>
+        <location filename="../syncthingconnection.cpp" line="530"/>
         <source>Connection configuration is insufficient.</source>
         <translation>缺少连接配置。</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="733"/>
+        <location filename="../syncthingconnection.cpp" line="798"/>
         <source>Unable to parse timestamp &quot;%1&quot; (%2): %3</source>
         <translation>无法解析时间戳 &quot;%1&quot; (%2): %3</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="800"/>
+        <location filename="../syncthingconnection.cpp" line="871"/>
         <source>Unable to locate certificate used by Syncthing.</source>
         <translation>无法找到 Syncthing 使用的证书。</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="806"/>
+        <location filename="../syncthingconnection.cpp" line="877"/>
         <source>Unable to load certificate used by Syncthing.</source>
         <translation>无法加载 Syncthing 使用的证书。</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="976"/>
+        <location filename="../syncthingconnection.cpp" line="1070"/>
         <source>at offset %1</source>
         <translation>在偏移量 %1 处</translation>
     </message>
@@ -264,47 +274,47 @@
 <context>
     <name>Data::SyncthingNotifier</name>
     <message>
-        <location filename="../syncthingnotifier.cpp" line="75"/>
+        <location filename="../syncthingnotifier.cpp" line="82"/>
         <source>Device %1 (%2) wants to connect.</source>
         <translation>设备 %1 (%2) 想要连接。</translation>
     </message>
     <message>
-        <location filename="../syncthingnotifier.cpp" line="89"/>
+        <location filename="../syncthingnotifier.cpp" line="96"/>
         <source>Device </source>
         <translation>设备 </translation>
     </message>
     <message>
-        <location filename="../syncthingnotifier.cpp" line="89"/>
+        <location filename="../syncthingnotifier.cpp" line="96"/>
         <source>Unknown device </source>
         <translation>未知设备 </translation>
     </message>
     <message>
-        <location filename="../syncthingnotifier.cpp" line="91"/>
+        <location filename="../syncthingnotifier.cpp" line="98"/>
         <source> wants to share folder %1.</source>
         <translation> 想要分享目录 %1。</translation>
     </message>
     <message>
-        <location filename="../syncthingnotifier.cpp" line="93"/>
+        <location filename="../syncthingnotifier.cpp" line="100"/>
         <source> wants to share folder %1 (%2).</source>
         <translation> 想要分享目录  %1 (%2)。</translation>
     </message>
     <message>
-        <location filename="../syncthingnotifier.cpp" line="108"/>
+        <location filename="../syncthingnotifier.cpp" line="115"/>
         <source>Failed to start Syncthing</source>
         <translation>启动 Syncthing 失败</translation>
     </message>
     <message>
-        <location filename="../syncthingnotifier.cpp" line="109"/>
+        <location filename="../syncthingnotifier.cpp" line="116"/>
         <source>Maybe the configured binary path is wrong or the binary is not marked as executable.</source>
         <translation>也许配置的二进制文件路径是错误的，或者二进制文件没有被标记为可执行文件。</translation>
     </message>
     <message>
-        <location filename="../syncthingnotifier.cpp" line="112"/>
+        <location filename="../syncthingnotifier.cpp" line="119"/>
         <source>Syncthing crashed</source>
         <translation>Syncthing 崩溃了</translation>
     </message>
     <message>
-        <location filename="../syncthingnotifier.cpp" line="115"/>
+        <location filename="../syncthingnotifier.cpp" line="122"/>
         <source>Syncthing launcher error occurred</source>
         <translation>Syncthing 启动器发生错误</translation>
     </message>
