@@ -379,6 +379,29 @@
         <translation>Postup</translation>
     </message>
 </context>
+<context>
+    <name>Data::SyncthingFileModel</name>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="141"/>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="143"/>
+        <source>Size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="145"/>
+        <source>Last modified</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="201"/>
+        <source>Refresh</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>Data::SyncthingRecentChangesModel</name>
     <message>
