@@ -4,7 +4,7 @@
 <context>
     <name>Data::SyncthingLauncher</name>
     <message>
-        <location filename="../misc/syncthinglauncher.cpp" line="83"/>
+        <location filename="../misc/syncthinglauncher.cpp" line="151"/>
         <source>Not built with libsyncthing support.</source>
         <translation>未使用 libsyncthing 支持构建。</translation>
     </message>
@@ -12,10 +12,25 @@
 <context>
     <name>QtGui</name>
     <message>
-        <location filename="../webview/webviewdialog.cpp" line="246"/>
+        <location filename="../webview/webviewdialog.cpp" line="249"/>
         <source>Unable to open Syncthing UI via &quot;%1&quot;: %2</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../settings/settingsdialog.cpp" line="89"/>
+        <source>The network connection is currently considered metered.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/settingsdialog.cpp" line="90"/>
+        <source>The network connection is currently not considered metered.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/settingsdialog.cpp" line="91"/>
+        <source>Unable to determine whether the network connection is metered; assuming an unmetered connection.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QtGui::AppearanceOptionPage</name>
@@ -367,32 +382,32 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="792"/>
+        <location filename="../settings/settingsdialog.cpp" line="817"/>
         <source>This is achieved by adding a *.desktop file under &lt;i&gt;~/.config/autostart&lt;/i&gt; so the setting only affects the current user.</source>
         <translation>这是通过在 &lt;i&gt;~/.config/autostart&lt;/i&gt; 下添加 *.desktop 文件来实现的，因此该设置仅影响当前用户。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="795"/>
+        <location filename="../settings/settingsdialog.cpp" line="820"/>
         <source>This is achieved by adding a registry key under &lt;i&gt;HKEY_CURRENT_USER\SOFTWARE\Microsoft\Windows\CurrentVersion\Run&lt;/i&gt; so the setting only affects the current user. Note that the startup entry is invalidated when moving &lt;i&gt;syncthingtray.exe&lt;/i&gt;.</source>
         <translation>这是通过在 &lt;i&gt;HKEY_CURRENT_USER\SOFTWARE\Microsoft\Windows\CurrentVersion\Run&lt;/i&gt; 下添加注册表项来实现的，因此该设置仅影响当前用户。 请注意，移动 &lt;i&gt;syncthingtray.exe&lt;/i&gt; 时启动项无效。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="799"/>
+        <location filename="../settings/settingsdialog.cpp" line="824"/>
         <source>This is achieved by adding a *.plist file under &lt;i&gt;~/Library/LaunchAgents&lt;/i&gt; so the setting only affects the current user.</source>
         <translation>这是通过在 &lt;i&gt;~/Library/LaunchAgents&lt;/i&gt; 下添加 *.plist 文件来实现的，因此该设置仅影响当前用户。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="803"/>
+        <location filename="../settings/settingsdialog.cpp" line="828"/>
         <source>This feature has not been implemented for your platform (yet).</source>
         <translation>此功能尚未为您的平台实现。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1010"/>
+        <location filename="../settings/settingsdialog.cpp" line="1036"/>
         <source>unable to modify startup entry</source>
         <translation>无法修改启动项</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1040"/>
+        <location filename="../settings/settingsdialog.cpp" line="1066"/>
         <source>There is already an autostart entry for &quot;%1&quot;. It will not be overridden when applying changes unless you delete it first.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -465,7 +480,7 @@ The Web UI will be opened in the default web browser instead.</source>
     </message>
     <message>
         <location filename="../settings/builtinwebviewoptionpage.ui" line="12"/>
-        <location filename="../settings/settingsdialog.cpp" line="1614"/>
+        <location filename="../settings/settingsdialog.cpp" line="1651"/>
         <source>Built-in web view</source>
         <translation type="unfinished"></translation>
     </message>
@@ -485,7 +500,7 @@ The Web UI will be opened in the default web browser instead.</source>
         <translation type="unfinished">当前未显示时保持网页视图运行</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1616"/>
+        <location filename="../settings/settingsdialog.cpp" line="1653"/>
         <source>Syncthing Tray has not been built with vieb view support utilizing either Qt WebKit or Qt WebEngine.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -548,7 +563,7 @@ The Web UI will be opened in the default web browser instead.</source>
         <translation>密码</translation>
     </message>
     <message>
-        <location filename="../settings/connectionoptionpage.ui" line="557"/>
+        <location filename="../settings/connectionoptionpage.ui" line="512"/>
         <source>API key</source>
         <translation>API 密钥</translation>
     </message>
@@ -592,8 +607,8 @@ The Web UI will be opened in the default web browser instead.</source>
         <location filename="../settings/connectionoptionpage.ui" line="381"/>
         <location filename="../settings/connectionoptionpage.ui" line="410"/>
         <location filename="../settings/connectionoptionpage.ui" line="442"/>
-        <location filename="../settings/connectionoptionpage.ui" line="584"/>
-        <location filename="../settings/connectionoptionpage.ui" line="636"/>
+        <location filename="../settings/connectionoptionpage.ui" line="539"/>
+        <location filename="../settings/connectionoptionpage.ui" line="591"/>
         <source> ms</source>
         <translation> 毫秒</translation>
     </message>
@@ -653,87 +668,97 @@ The Web UI will be opened in the default web browser instead.</source>
         <translation>总体状态</translation>
     </message>
     <message>
-        <location filename="../settings/connectionoptionpage.ui" line="486"/>
-        <source>Select what information should be considered to compute the overall status:</source>
-        <translation>选择应考虑哪些信息来计算总体状态：</translation>
-    </message>
-    <message>
-        <location filename="../settings/connectionoptionpage.ui" line="526"/>
-        <source>Current status</source>
-        <translation>目前状态</translation>
-    </message>
-    <message>
-        <location filename="../settings/connectionoptionpage.ui" line="533"/>
-        <source>disconnected</source>
-        <translation>已断连</translation>
-    </message>
-    <message>
-        <location filename="../settings/connectionoptionpage.ui" line="546"/>
-        <source>Apply connection settings and try to reconnect with the currently selected config</source>
-        <translation>应用连接设置并尝试使用当前选择的配置重新连接</translation>
-    </message>
-    <message>
-        <location filename="../settings/connectionoptionpage.ui" line="564"/>
-        <source>The API key displayed in Syncthing&apos;s settings dialog</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settings/connectionoptionpage.ui" line="571"/>
-        <source>The timeout for normal requests to Syncthing&apos;s API. Set to zero to enforce no timeout.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settings/connectionoptionpage.ui" line="574"/>
-        <source>Transfer timeout</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settings/connectionoptionpage.ui" line="581"/>
-        <source>no timeout</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settings/connectionoptionpage.ui" line="613"/>
-        <source>Show advanced configuration</source>
+        <location filename="../settings/connectionoptionpage.ui" line="611"/>
+        <source>Options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../settings/connectionoptionpage.ui" line="623"/>
+        <source>Select what information should be considered to compute the overall status:</source>
+        <translation>选择应考虑哪些信息来计算总体状态：</translation>
+    </message>
+    <message>
+        <location filename="../settings/connectionoptionpage.ui" line="481"/>
+        <source>Current status</source>
+        <translation>目前状态</translation>
+    </message>
+    <message>
+        <location filename="../settings/connectionoptionpage.ui" line="488"/>
+        <source>disconnected</source>
+        <translation>已断连</translation>
+    </message>
+    <message>
+        <location filename="../settings/connectionoptionpage.ui" line="501"/>
+        <source>Apply connection settings and try to reconnect with the currently selected config</source>
+        <translation>应用连接设置并尝试使用当前选择的配置重新连接</translation>
+    </message>
+    <message>
+        <location filename="../settings/connectionoptionpage.ui" line="519"/>
+        <source>The API key displayed in Syncthing&apos;s settings dialog</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/connectionoptionpage.ui" line="526"/>
+        <source>The timeout for normal requests to Syncthing&apos;s API. Set to zero to enforce no timeout.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/connectionoptionpage.ui" line="529"/>
+        <source>Transfer timeout</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/connectionoptionpage.ui" line="536"/>
+        <source>no timeout</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/connectionoptionpage.ui" line="568"/>
+        <source>Show advanced configuration</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/connectionoptionpage.ui" line="578"/>
         <source>The timeout for long-polling requests to Syncthing&apos;s event API. Set to zero to use Syncthing&apos;s default timeout and no timeout being enforced from Syncthing Tray&apos;s side.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settings/connectionoptionpage.ui" line="626"/>
+        <location filename="../settings/connectionoptionpage.ui" line="581"/>
         <source>Long polling int.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settings/connectionoptionpage.ui" line="633"/>
+        <location filename="../settings/connectionoptionpage.ui" line="588"/>
         <source>Syncthing&apos;s default with no timeout</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="111"/>
+        <location filename="../settings/connectionoptionpage.ui" line="604"/>
+        <source>Pause all devices while the local network connection is metered</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/settingsdialog.cpp" line="127"/>
         <source>Auto-detected for local instance</source>
         <translation>本地实例自动检测</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="149"/>
+        <location filename="../settings/settingsdialog.cpp" line="171"/>
         <source>Select Syncthing config file</source>
         <translation>选择 Syncthing 配置文件</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="157"/>
+        <location filename="../settings/settingsdialog.cpp" line="179"/>
         <source>Unable to parse the Syncthing config file.</source>
         <translation>无法解析 Syncthing 配置文件。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="252"/>
+        <location filename="../settings/settingsdialog.cpp" line="276"/>
         <source>Unable to load specified certificate &quot;%1&quot;.</source>
         <translation>无法加载指定的证书 &quot;%1&quot;。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="277"/>
+        <location filename="../settings/settingsdialog.cpp" line="301"/>
         <source>Instance %1</source>
         <translation>实例 %1</translation>
     </message>
@@ -960,12 +985,12 @@ The Web UI will be opened in the default web browser instead.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1590"/>
+        <location filename="../settings/settingsdialog.cpp" line="1627"/>
         <source>Custom command to launch Syncthing&apos;s UI - </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1591"/>
+        <location filename="../settings/settingsdialog.cpp" line="1628"/>
         <source>&lt;p&gt;Enter a custom command to launch Syncthing&apos;s UI. The expression &lt;code&gt;%SYNCTHING_URL%&lt;/code&gt; will be replaced with the Syncthing-URL.&lt;/p&gt;&lt;p&gt;Leave the command empty to use the auto-detection.&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1046,47 +1071,47 @@ The Web UI will be opened in the default web browser instead.</source>
 <context>
     <name>QtGui::IconsOptionPageBase</name>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="614"/>
+        <location filename="../settings/settingsdialog.cpp" line="639"/>
         <source>UI icons</source>
         <translation>UI 图标</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="616"/>
+        <location filename="../settings/settingsdialog.cpp" line="641"/>
         <source>These icon settings are used within Syncthing Tray&apos;s UI.</source>
         <translation>这些图标设置在 Syncthing Tray 的 UI 中使用。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="620"/>
+        <location filename="../settings/settingsdialog.cpp" line="645"/>
         <source>System icons</source>
         <translation>系统图标</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="621"/>
+        <location filename="../settings/settingsdialog.cpp" line="646"/>
         <source>These icon settings are used for the system tray icon and the notifications.</source>
         <translation>这些图标设置用于系统托盘图标和通知。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="623"/>
+        <location filename="../settings/settingsdialog.cpp" line="648"/>
         <source>Use same settings as for UI icons</source>
         <translation>使用与 UI 图标相同的设置</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="684"/>
+        <location filename="../settings/settingsdialog.cpp" line="709"/>
         <source>Colorful background with gradient (default)</source>
         <translation>带渐变的彩色背景（默认）</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="689"/>
+        <location filename="../settings/settingsdialog.cpp" line="714"/>
         <source>Transparent background and dark foreground (for bright themes)</source>
         <translation>透明背景和深色前景（适用于明亮的主题）</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="694"/>
+        <location filename="../settings/settingsdialog.cpp" line="719"/>
         <source>Transparent background and bright foreground (for dark themes)</source>
         <translation>透明背景和明亮前景（用于深色主题）</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="710"/>
+        <location filename="../settings/settingsdialog.cpp" line="735"/>
         <source>%1 px (scaled to %2 px)</source>
         <translation>%1 像素（缩放到 %2 像素）</translation>
     </message>
@@ -1150,57 +1175,72 @@ The Web UI will be opened in the default web browser instead.</source>
     </message>
     <message>
         <location filename="../settings/launcheroptionpage.ui" line="70"/>
+        <source>Set directory for configuration and keys</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/launcheroptionpage.ui" line="73"/>
         <source>Config directory</source>
         <translation>配置目录</translation>
     </message>
     <message>
-        <location filename="../settings/launcheroptionpage.ui" line="80"/>
+        <location filename="../settings/launcheroptionpage.ui" line="83"/>
         <source>Log level</source>
         <translation>日志等级</translation>
     </message>
     <message>
-        <location filename="../settings/launcheroptionpage.ui" line="88"/>
+        <location filename="../settings/launcheroptionpage.ui" line="91"/>
         <source>Debug</source>
         <translation>Debug</translation>
     </message>
     <message>
-        <location filename="../settings/launcheroptionpage.ui" line="93"/>
+        <location filename="../settings/launcheroptionpage.ui" line="96"/>
         <source>Verbose</source>
         <translation>Verbose</translation>
     </message>
     <message>
-        <location filename="../settings/launcheroptionpage.ui" line="98"/>
+        <location filename="../settings/launcheroptionpage.ui" line="101"/>
         <source>Info</source>
         <translation>Info</translation>
     </message>
     <message>
-        <location filename="../settings/launcheroptionpage.ui" line="103"/>
+        <location filename="../settings/launcheroptionpage.ui" line="106"/>
         <source>Warning</source>
         <translation>Warning</translation>
     </message>
     <message>
-        <location filename="../settings/launcheroptionpage.ui" line="108"/>
+        <location filename="../settings/launcheroptionpage.ui" line="111"/>
         <source>Fatal</source>
         <translation>Fatal</translation>
     </message>
     <message>
-        <location filename="../settings/launcheroptionpage.ui" line="116"/>
+        <location filename="../settings/launcheroptionpage.ui" line="119"/>
+        <source>Set database directory (falls back to config directory if empty)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/launcheroptionpage.ui" line="122"/>
         <source>Data directory</source>
         <translation>数据目录</translation>
     </message>
     <message>
-        <location filename="../settings/launcheroptionpage.ui" line="129"/>
+        <location filename="../settings/launcheroptionpage.ui" line="135"/>
         <source>Show start/stop button on tray for local instance</source>
         <translation>在托盘上为本地实例显示开始/停止按钮</translation>
     </message>
     <message>
-        <location filename="../settings/launcheroptionpage.ui" line="136"/>
+        <location filename="../settings/launcheroptionpage.ui" line="142"/>
         <source>Consider process status for notifications and reconnect attempts concerning local instance
  • Don&apos;t reconnect when the process is not running
  • Try to reconnect when starting the process
  • Suppress notification about disconnect when Syncthing has been stopped manually</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../settings/launcheroptionpage.ui" line="152"/>
+        <source>Stop automatically when network connection is metered</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Consider process status for reconnect attempts to local instance
  • Don&apos;t reconnect when the process is not running
@@ -1210,108 +1250,108 @@ The Web UI will be opened in the default web browser instead.</source>
   • 启动进程时尝试重新连接</translation>
     </message>
     <message>
-        <location filename="../settings/launcheroptionpage.ui" line="166"/>
+        <location filename="../settings/launcheroptionpage.ui" line="179"/>
         <source>Syncthing log (interleaved stdout/stderr)</source>
         <translation>同步日志（交错的标准输出/标准错误）</translation>
     </message>
     <message>
-        <location filename="../settings/launcheroptionpage.ui" line="179"/>
+        <location filename="../settings/launcheroptionpage.ui" line="192"/>
         <source>Apply and launch now</source>
         <translation>立即应用并启动</translation>
     </message>
     <message>
-        <location filename="../settings/launcheroptionpage.ui" line="196"/>
-        <location filename="../settings/settingsdialog.cpp" line="1209"/>
+        <location filename="../settings/launcheroptionpage.ui" line="209"/>
+        <location filename="../settings/settingsdialog.cpp" line="1246"/>
         <source>Stop launched instance</source>
         <translation>停止启动的实例</translation>
     </message>
     <message>
-        <location filename="../settings/launcheroptionpage.ui" line="215"/>
+        <location filename="../settings/launcheroptionpage.ui" line="228"/>
         <source>No log messages available yet</source>
         <translation>尚无可用的日志消息</translation>
     </message>
     <message>
-        <location filename="../settings/launcheroptionpage.ui" line="222"/>
+        <location filename="../settings/launcheroptionpage.ui" line="235"/>
         <source>Ensure latest log is visible</source>
         <translation>确保最新日志可见</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1081"/>
+        <location filename="../settings/settingsdialog.cpp" line="1107"/>
         <source>%1-launcher</source>
         <translation>%1-启动器</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1082"/>
+        <location filename="../settings/settingsdialog.cpp" line="1108"/>
         <source>Launch %1 when starting the tray icon</source>
         <translation>启动托盘图标时启动 %1</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1085"/>
+        <location filename="../settings/settingsdialog.cpp" line="1111"/>
         <source>%1 executable</source>
         <translation>%1 可执行文件</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1086"/>
+        <location filename="../settings/settingsdialog.cpp" line="1112"/>
         <source>%1 log (interleaved stdout/stderr)</source>
         <translation>%1 日志（交错的标准输出/标准错误）</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1102"/>
+        <location filename="../settings/settingsdialog.cpp" line="1129"/>
         <source>Restore default</source>
         <translation>还原至默认</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1108"/>
+        <location filename="../settings/settingsdialog.cpp" line="1135"/>
         <source>Show Syncthing releases/downloads</source>
         <translation>显示 Syncthing 发布/下载</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1244"/>
+        <location filename="../settings/settingsdialog.cpp" line="1281"/>
         <source>%1 exited with exit code %2</source>
         <translation>%1 退出，退出代码为 %2</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1247"/>
+        <location filename="../settings/settingsdialog.cpp" line="1284"/>
         <source>%1 crashed with exit code %2</source>
         <translation>%1 崩溃，退出代码为 %2</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1280"/>
+        <location filename="../settings/settingsdialog.cpp" line="1317"/>
         <source>failed to start (e.g. executable does not exist or not permission error)</source>
         <translation>启动失败（例如可执行文件不存在或没有权限）</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1283"/>
+        <location filename="../settings/settingsdialog.cpp" line="1320"/>
         <source>process crashed</source>
         <translation>进程崩溃</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1286"/>
+        <location filename="../settings/settingsdialog.cpp" line="1323"/>
         <source>timeout error</source>
         <translation>超时错误</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1289"/>
+        <location filename="../settings/settingsdialog.cpp" line="1326"/>
         <source>read error</source>
         <translation>读取错误</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1292"/>
+        <location filename="../settings/settingsdialog.cpp" line="1329"/>
         <source>write error</source>
         <translation>写入错误</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1295"/>
+        <location filename="../settings/settingsdialog.cpp" line="1332"/>
         <source>unknown process error</source>
         <translation>未知进程错误</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1298"/>
+        <location filename="../settings/settingsdialog.cpp" line="1335"/>
         <source>An error occurred when running %1: %2</source>
         <translation>运行 %1 时出错: %2</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1351"/>
+        <location filename="../settings/settingsdialog.cpp" line="1388"/>
         <source>Kill launched instance</source>
         <translation>强制终止启动的实例</translation>
     </message>
@@ -1510,7 +1550,7 @@ The Web UI will be opened in the default web browser instead.</source>
         <translation> 秒</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="459"/>
+        <location filename="../settings/settingsdialog.cpp" line="484"/>
         <source>Configured to use D-Bus notifications but D-Bus notification daemon seems unavailabe.</source>
         <translation>配置为使用 DBus 通知，但 D-Bus 通知守护程序似乎不可用。</translation>
     </message>
@@ -1518,55 +1558,60 @@ The Web UI will be opened in the default web browser instead.</source>
 <context>
     <name>QtGui::OtherDialogs</name>
     <message>
-        <location filename="../misc/otherdialogs.cpp" line="26"/>
+        <location filename="../misc/otherdialogs.cpp" line="30"/>
         <source>Own device ID</source>
         <translation>本设备 ID</translation>
     </message>
     <message>
-        <location filename="../misc/otherdialogs.cpp" line="36"/>
+        <location filename="../misc/otherdialogs.cpp" line="40"/>
         <source>device ID is unknown</source>
         <translation>设备 ID 未知</translation>
     </message>
     <message>
-        <location filename="../misc/otherdialogs.cpp" line="44"/>
+        <location filename="../misc/otherdialogs.cpp" line="48"/>
         <source>Copy to clipboard</source>
         <translation>复制至剪贴板</translation>
     </message>
+    <message>
+        <location filename="../misc/otherdialogs.cpp" line="85"/>
+        <source>Remote/global tree of folder &quot;%1&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QtGui::SettingsDialog</name>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1665"/>
+        <location filename="../settings/settingsdialog.cpp" line="1702"/>
         <source>Tray</source>
         <translation>托盘</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1673"/>
+        <location filename="../settings/settingsdialog.cpp" line="1710"/>
         <source>Web view</source>
         <translation>网页视图</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1680"/>
+        <location filename="../settings/settingsdialog.cpp" line="1717"/>
         <source>Startup</source>
         <translation>启动</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1682"/>
+        <location filename="../settings/settingsdialog.cpp" line="1719"/>
         <source>additional tool</source>
         <translation>附加工具</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1682"/>
+        <location filename="../settings/settingsdialog.cpp" line="1719"/>
         <source>Extra launcher</source>
         <translation>额外启动器</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1705"/>
+        <location filename="../settings/settingsdialog.cpp" line="1742"/>
         <source>Settings</source>
         <translation>设置</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1711"/>
+        <location filename="../settings/settingsdialog.cpp" line="1748"/>
         <source>Start wizard</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1750,8 +1795,8 @@ This dialog closes automatically when the process finally terminates.</source>
         <location filename="../settings/systemdoptionpage.ui" line="110"/>
         <location filename="../settings/systemdoptionpage.ui" line="165"/>
         <location filename="../settings/systemdoptionpage.ui" line="254"/>
-        <location filename="../settings/settingsdialog.cpp" line="1489"/>
-        <location filename="../settings/settingsdialog.cpp" line="1498"/>
+        <location filename="../settings/settingsdialog.cpp" line="1526"/>
+        <location filename="../settings/settingsdialog.cpp" line="1535"/>
         <source>unknown</source>
         <translation>未知</translation>
     </message>
@@ -1786,27 +1831,27 @@ This dialog closes automatically when the process finally terminates.</source>
         <translation>禁用</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1387"/>
+        <location filename="../settings/settingsdialog.cpp" line="1424"/>
         <source>Reload all unit files</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1425"/>
+        <location filename="../settings/settingsdialog.cpp" line="1462"/>
         <source>It is not possible to show the start/stop button for the systemd service and the internal launcher at the same time. The systemd service precedes.</source>
         <translation>无法同时显示 systemd 服务和内部启动器的启动/停止按钮。 systemd 服务优先。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1431"/>
+        <location filename="../settings/settingsdialog.cpp" line="1468"/>
         <source>It is not possible to consider the systemd service and the internal launcher for reconnects at the same time. The systemd service precedes.</source>
         <translation>无法同时考虑 systemd 服务和内部启动器进行重新连接。 systemd 服务优先。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1462"/>
+        <location filename="../settings/settingsdialog.cpp" line="1499"/>
         <source>specified unit is either inactive or doesn&apos;t exist</source>
         <translation>指定的单位不活动或不存在</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1484"/>
+        <location filename="../settings/settingsdialog.cpp" line="1521"/>
         <source>since </source>
         <translation>自从 </translation>
     </message>
@@ -1827,7 +1872,7 @@ This dialog closes automatically when the process finally terminates.</source>
         <translation type="vanished">选择 Syncthing 目录的路径 ...</translation>
     </message>
     <message>
-        <location filename="../webview/webpage.cpp" line="489"/>
+        <location filename="../webview/webpage.cpp" line="492"/>
         <source>Select path for Syncthing directory …</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1835,7 +1880,7 @@ This dialog closes automatically when the process finally terminates.</source>
 <context>
     <name>QtGui::WebViewDialog</name>
     <message>
-        <location filename="../webview/webviewdialog.cpp" line="43"/>
+        <location filename="../webview/webviewdialog.cpp" line="46"/>
         <source>Syncthing</source>
         <translation>Syncthing</translation>
     </message>
@@ -2147,7 +2192,7 @@ The Web UI will be opened in the default web browser instead.</source>
 <context>
     <name>Settings::Connection</name>
     <message>
-        <location filename="../settings/settings.cpp" line="662"/>
+        <location filename="../settings/settings.cpp" line="667"/>
         <source>Backup of %1 (created by wizard)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -2155,7 +2200,7 @@ The Web UI will be opened in the default web browser instead.</source>
 <context>
     <name>Settings::restore</name>
     <message>
-        <location filename="../settings/settings.cpp" line="329"/>
+        <location filename="../settings/settings.cpp" line="331"/>
         <source>Unable to load certificate &quot;%1&quot; when restoring settings.</source>
         <translation>还原设置时无法加载证书 &quot;%1&quot;。</translation>
     </message>
