@@ -4,9 +4,12 @@
 
 #include "../settings/settings.h"
 
-#include <syncthingconnector/syncthingconnection.h>
+// use meta-data of syncthingtray application here
+// note: Using the meta-data from the library would make more sense but this breaks
+//       unity builds.
+#include "resources/../../tray/resources/config.h"
 
-#include "resources/config.h"
+#include <syncthingconnector/syncthingconnection.h>
 
 #include <QAuthenticator>
 #include <QDesktopServices>
@@ -69,7 +72,7 @@ WebPage::WebPage(WebViewDialog *dlg, SYNCTHINGWIDGETS_WEB_VIEW *view)
 #else
         connect(this->mainFrame(), &QWebFrame::urlChanged, this, &WebPage::delegateNewWindowToExternalBrowser);
 #endif
-        // -> there need to be a view, though
+        // -> there needs to be a temporariy view, though
         m_view = new SYNCTHINGWIDGETS_WEB_VIEW;
         m_view->setPage(this);
         setParent(m_view);
@@ -104,7 +107,7 @@ bool WebPage::isSamePage(const QUrl &url1, const QUrl &url2)
 SYNCTHINGWIDGETS_WEB_PAGE *WebPage::createWindow(SYNCTHINGWIDGETS_WEB_PAGE::WebWindowType type)
 {
     Q_UNUSED(type)
-    return new WebPage;
+    return new WebPage(profile());
 }
 
 #ifdef SYNCTHINGWIDGETS_USE_WEBENGINE
