@@ -203,6 +203,7 @@ TrayWidget::TrayWidget(TrayMenu *parent)
     connect(m_ui->dirsTreeView, &DirView::scanDir, this, &TrayWidget::scanDir);
     connect(m_ui->dirsTreeView, &DirView::pauseResumeDir, this, &TrayWidget::pauseResumeDir);
     connect(m_ui->devsTreeView, &DevView::pauseResumeDev, this, &TrayWidget::pauseResumeDev);
+    connect(m_ui->dirsTreeView, &DirView::browseRemoteFiles, this, &TrayWidget::browseRemoteFiles);
     connect(m_ui->downloadsTreeView, &DownloadView::openDir, this, &TrayWidget::openDir);
     connect(m_ui->downloadsTreeView, &DownloadView::openItemDir, this, &TrayWidget::openItemDir);
     connect(m_ui->recentChangesTreeView, &QTreeView::customContextMenuRequested, this, &TrayWidget::showRecentChangesContextMenu);
@@ -639,6 +640,13 @@ bool TrayWidget::event(QEvent *event)
             m_menu->icon()->updateStatusIconAndText();
         }
         break;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 6, 0)
+    case QEvent::DevicePixelRatioChange:
+        setLabelPixmaps();
+        setTrafficPixmaps(true);
+        IconManager::instance().update();
+        break;
+#endif
     default:;
     }
     return res;
@@ -701,6 +709,14 @@ void TrayWidget::pauseResumeDir(const SyncthingDir &dir)
     }
 }
 
+void TrayWidget::browseRemoteFiles(const Data::SyncthingDir &dir)
+{
+    auto *const dlg = browseRemoteFilesDialog(m_connection, dir, this);
+    dlg->resize(600, 500);
+    centerWidget(dlg);
+    dlg->show();
+}
+
 void TrayWidget::showRecentChangesContextMenu(const QPoint &position)
 {
     const auto *const selectionModel = m_ui->recentChangesTreeView->selectionModel();
